==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbERotatedTableEx.h <==
/*
    TCFbERotatedTableEx.h    December 4, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbERotatedTableExH
#define TCFbERotatedTableExH
//---------------------------------------------------------------------------
// #include "Maprof.h"

#include "TCFbECell.h"
#include "TCFbEToolkit.h"
#include "TCFbERowColumnCachedTable.h"
#include "TCFbEColumnCachedTable.h"
#include "TCFbERowCachedTable.h"
#include "TCFbERowRowCachedTable.h"
#include "TCFbECustomTableEx.h"
#include "TCFbETableEx.h"
//---------------------------------------------------------------------------
// v@\tLbVue[u
class TCFbERotatedTableEx : public TCFbECustomTableEx
{
public:
    virtual __fastcall TCFbERotatedTableEx(void);    // RXgN^iLbV쐬
    virtual __fastcall TCFbERotatedTableEx(TStringList* RowLabelList, TStringList* ColumnLabelList);    // w肳ꂽse[u쐬
    virtual __fastcall TCFbERotatedTableEx(TStringList* SourceCsvStringList);   // RXgN^
    __fastcall ~TCFbERotatedTableEx();    // fXgN^

    virtual void __fastcall ParentCellIsUpdated(int RowIndex, int ColumnIndex); // eLbṼZXVꂽ
    virtual int __fastcall  ParentAddRow(const char* RowLabel);          // eLbV̍sǉꂽ
    virtual int __fastcall  ParentAddColumn(const char* ColumnLabel);    // eLbV̗񂪒ǉꂽ
    virtual void __fastcall ParentDeleteRowByIndex(int TargetRowIndex); // eLbV̍s폜ꂽ
    virtual void __fastcall ParentDeleteColumnByIndex(int TargetColumnIndex);   // eLbV̗񂪍폜ꂽ

protected:
    virtual TCFbECachedTable* __fastcall CreateClone(void);             // g̃N[쐬
    virtual TCFbECachedTable* __fastcall CreateRotatedClone(void);      // g̍sƗ񂪓ւN[쐬

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_4_47_83.zip: docfbe_2_4_47_83/source/TCFbERotatedTableEx.h <==
/*
    TCFbERotatedTableEx.h    December 4, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbERotatedTableExH
#define TCFbERotatedTableExH
//---------------------------------------------------------------------------
// #include "Maprof.h"

#include "TCFbECell.h"
#include "TCFbEToolkit.h"
#include "TCFbERowColumnCachedTable.h"
#include "TCFbEColumnCachedTable.h"
#include "TCFbERowCachedTable.h"
#include "TCFbERowRowCachedTable.h"
#include "TCFbECustomTableEx.h"
#include "TCFbETableEx.h"
//---------------------------------------------------------------------------
// v@\tLbVue[u
class TCFbERotatedTableEx : public TCFbECustomTableEx
{
public:
    virtual __fastcall TCFbERotatedTableEx(void);    // RXgN^iLbV쐬
    virtual __fastcall TCFbERotatedTableEx(TStringList* RowLabelList, TStringList* ColumnLabelList);            // w肳ꂽse[u쐬
    virtual __fastcall TCFbERotatedTableEx(TStringList* SourceCsvStringList, AnsiString QualitativeIndicator);  // RXgN^
    __fastcall ~TCFbERotatedTableEx();    // fXgN^

    virtual void __fastcall ParentCellIsUpdated(int RowIndex, int ColumnIndex); // eLbṼZXVꂽ
    virtual int __fastcall  ParentAddRow(const char* RowLabel, const bool IsQualitative);          // eLbV̍sǉꂽ
    virtual int __fastcall  ParentAddColumn(const char* ColumnLabel, const bool IsQualitative);    // eLbV̗񂪒ǉꂽ
    virtual void __fastcall ParentDeleteRowByIndex(int TargetRowIndex);         // eLbV̍s폜ꂽ
    virtual void __fastcall ParentDeleteColumnByIndex(int TargetColumnIndex);   // eLbV̗񂪍폜ꂽ

protected:
    virtual TCFbECachedTable* __fastcall CreateClone(void);             // g̃N[쐬
    virtual TCFbECachedTable* __fastcall CreateRotatedClone(void);      // g̍sƗ񂪓ւN[쐬

private:

};
//---------------------------------------------------------------------------
#endif
